@@ -1,4 +1,5 @@
 import json
+from django.http import Http404
 from rest_framework_proxy.views import ProxyView
 from vtixy_proxy import settings
 
@@ -35,4 +36,17 @@ class OrdersProxy(VTIXyProxyView):
 
 
 class OrderDetailsProxy(VTIXyProxyView):
-    source = 'orders/%(pk)s/'
\ No newline at end of file
+    source = 'orders/%(pk)s/'
+
+    def get(self, request, *args, **kwargs):
+
+        if not request.GET.get('transaction_id', None):
+            raise Http404
+
+        response = super(OrderDetailsProxy, self).get(request, *args, **kwargs)
+
+        transaction_parts = response.data['transaction_id'].split('.')
+        if request.GET['transaction_id'] != transaction_parts[0]:
+            raise Http404
+
+        return response
\ No newline at end of file
